@@ -20,29 +20,29 @@ def get_time_from_str(s: str) -> int:
     if s.isdigit():
         return int(s)
     else:
-        res = 0
+        sec = 0
         m_ind = s.find("m")
         if m_ind != -1:
-            res += 60 * int(s[:m_ind])
+            sec += 60 * int(s[:m_ind])
 
         s_ind = s.find("s")
         if s_ind == -1:
-            return res
-        res += int(s[m_ind + 1:s_ind])
-        return res
+            return sec
+        sec += int(s[m_ind + 1:s_ind])
+        return sec
 
 
 def inner_str(s: str, d: dict) -> str:
-    starts: List[int] = []
-    ends: List[int] = []
+    start_secs: List[int] = []
+    end_secs: List[int] = []
     for i, c in enumerate(s):
-        if len(starts) == len(ends) and c == "{":
-            starts.append(i)
-        if len(starts) == len(ends) + 1 and c == "}":
-            ends.append(i)
+        if len(start_secs) == len(end_secs) and c == "{":
+            start_secs.append(i)
+        if len(start_secs) == len(end_secs) + 1 and c == "}":
+            end_secs.append(i)
 
     calcs = dict()
-    for start, end in zip(starts, ends):
+    for start, end in zip(start_secs, end_secs):
         target = s[start + 1:end]
         calcs[target] = eval(target, {}, d)
 
@@ -118,7 +118,9 @@ class ClockTimer:
         secs = list(sounds.keys())
         for i, (sec, sound) in enumerate(sounds.items()):
             spend_time = secs[i] - (0 if i == 0 else secs[i - 1])
-            for _ in tqdm(range(spend_time)):
+            tqdm_f = (lambda i: i) if sec == 0 else lambda i: tqdm(
+                i, bar_format="{l_bar}{bar}| {n_fmt}/{total_fmt} ")
+            for _ in tqdm_f(range(spend_time)):
                 time_sleep(1)
 
             notification = Notify()
