@@ -91,7 +91,12 @@ def main() -> None:
 
     jdata['title'] = jdata.get('title', get_title_from_json_filename(json_filename))
     clock_timer = ClockTimer.from_dict(jdata)
-    clock_timer.run()
+    try:
+        clock_timer.run()
+    except KeyboardInterrupt:
+        ...
+    finally:
+        print('bye')
 
 
 if __name__ == '__main__':
