@@ -36,9 +36,9 @@ def get_real_json_filename(path: str) -> str:
         return path
 
     if basedir.exists():
-        res = glob(str(basedir) + "/" + path)
-        if res:
-            return res[0]
+        filenames = glob(str(basedir) + "/" + path)
+        if filenames:
+            return filenames[0]
 
     while path.startswith("_"):
         path = path[1:]
@@ -57,9 +57,9 @@ def get_real_sound_filename(path: str) -> str:
 
     basedir = Path("~/.exclock/sound/").expanduser()
     if basedir.exists():
-        res = glob(str(basedir) + "/" + path)
-        if res:
-            return res[0]
+        filenames = glob(str(basedir) + "/" + path)
+        if filenames:
+            return filenames[0]
 
     while path.startswith("_"):
         path = path[1:]
